@@ -75,7 +75,7 @@ class CorporateMembershipTypeForm(forms.ModelForm):
                   'individual_threshold',
                   'individual_threshold_price',
                   'admin_only',
-                  'order',
+                  'position',
                   'status',
                   'status_detail',
                   )
@@ -574,7 +574,7 @@ class CorpFieldForm(forms.ModelForm):
                   'default_value',
                   'admin_only',
                   'css_class',
-                  'order'
+                  'position'
                   )
 
     def __init__(self, *args, **kwargs):
