@@ -44,12 +44,13 @@ def search(request, template_name="photos/search.html"):
     """ Photos search """
     query = request.GET.get('q', None)
     if get_setting('site', 'global', 'searchindex') and query:
-        photos = Image.objects.search(query, user=request.user).order_by('-create_dt')
+        photos = Image.objects.search(query, user=request.user)
     else:
         filters = get_query_filters(request.user, 'photos.view_image')
         photos = Image.objects.filter(filters).distinct()
         if not request.user.is_anonymous():
             photos = photos.select_related()
+
     photos = photos.order_by('-create_dt')
 
     EventLog.objects.log()
@@ -607,7 +608,6 @@ def photos_batch_edit(request, photoset_id=0, template_name="photos/batch-edit.h
 
     PhotoFormSet = modelformset_factory(
         Image,
-        can_delete=True,
         exclude=(
             'title_slug',
             'creator_username',
@@ -629,6 +629,10 @@ def photos_batch_edit(request, photoset_id=0, template_name="photos/batch-edit.h
         form = PhotoBatchEditForm(request.POST, instance=photo)
 
         if form.is_valid():
+            delete_photo = request.POST.get('delete')
+            if delete_photo:
+                photo.delete()
+
             photo = form.save()
             EventLog.objects.log(instance=photo)
             # set album cover if specified
@@ -651,6 +655,9 @@ def photos_batch_edit(request, photoset_id=0, template_name="photos/batch-edit.h
 
             return HttpResponse('Success')
 
+        else:
+            return HttpResponse('Failed')
+
     else:  # if request.method != POST
 
         # i would like to use the search index here; but it appears that
