@@ -448,8 +448,10 @@ def form_detail(request, slug, template="forms/form_detail.html"):
                 msg = EmailMessage(subject, admin_body, sender, email_copies, headers=email_headers)
                 msg.content_subtype = 'html'
                 for f in form_for_form.files.values():
+                    f.open()
                     f.seek(0)
                     msg.attach(f.name, f.read())
+                    f.close()
                 msg.send()
 
             # payment redirect
