@@ -11,6 +11,9 @@ urlpatterns = patterns('tendenci.apps.profiles.views',
     url(r'^export/(?P<task_id>[-\w]+)/download/$', 'export_download', name="profile.export_download"),
     url(r'^add/$', 'add', name="profile.add"),
     url(r'^edit/(?P<id>\d+)/$', 'edit', name="profile.edit"),
+    url(r'^similar/$', 'similar_profiles', name="profile.similar"),
+    url(r'^merge/(?P<sid>\d+)/$', 'merge_profiles', name="profile.merge_view"),
+    url(r'^merge/process/(?P<sid>\d+)/$', 'merge_process', name="profile.merge_process"),
     url(r'^edit_perms/(?P<id>\d+)/$', 'edit_user_perms', name="profile.edit_perms"),
     url(r'^avatar/(?P<id>\d+)/$', 'change_avatar', name="profile.change_avatar"),
     url(r'^delete/(?P<id>\d+)/$', 'delete', name="profile.delete"),
